@@ -15,7 +15,8 @@ from colorama import Fore
 
 init()
 
-from deployment.save_session import save_function
+from deployment.models import YhatModel
+from deployment.save_session import save_function, _get_source
 
 try:
     import pandas as pd
@@ -303,6 +304,12 @@ need to connect to the server first. try running "connect_to_socket"
         session: globals()
             your Python's session variables (i.e. "globals()")
         """
+        if _get_source(YhatModel.execute)==_get_source(model.execute):
+            msg = "'execute' method was not implemented. If you believe that you did"
+            msg += "implement the 'execute' method, check to make sure there isn't an "
+            msg += "indentation error."
+            raise Exception(msg)
+
         bundle = save_function(model, session)
         bundle["largefile"] = True
         bundle["username"] = self.username
@@ -389,8 +396,10 @@ if __name__=="__main__":
     print yh._convert_to_json({"x": 1})
     print yh._convert_to_json(df)
 
-    yh = Yhat("greg", "fCVZiLJhS95cnxOrsp5e2VSkk0GfypZqeRCntTD1nHA",
-            "http://localhost:8080/")
+    from yhat import credentials
+    creds = credentials.read()
+
+    yh = Yhat(creds['username'], creds['apikey'], "http://localhost:8080/")
 
     print yh.predict("mymodel", {"beer": "Coors Light"})
     yh.connect_to_socket("mymodel")
